==> tool-sql-2.6.0-sources.jar: io/ciera/tool/sql/architecture/interfaces/Port.java <==
package io.ciera.tool.sql.architecture.interfaces;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.component.ComponentDefinition;
import io.ciera.tool.sql.architecture.file.File;
import io.ciera.tool.sql.architecture.interfaces.Iface;
import io.ciera.tool.sql.architecture.interfaces.Port;
import io.ciera.tool.sql.architecture.interfaces.PortMessage;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.ooaofooa.component.C_PO;


public interface Port extends IModelInstance<Port,Sql> {

    // attributes
    public void setName( String ref_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public String getPackage() throws XtumlException;
    public void setPort_name( String m_port_name ) throws XtumlException;
    public String getPort_name() throws XtumlException;
    public boolean getProvider() throws XtumlException;
    public void setProvider( boolean m_provider ) throws XtumlException;
    public void setComp_name( String ref_comp_name ) throws XtumlException;
    public String getComp_name() throws XtumlException;
    public String getComp_package() throws XtumlException;
    public void setComp_package( String ref_comp_package ) throws XtumlException;
    public void setIface_name( String ref_iface_name ) throws XtumlException;
    public String getIface_name() throws XtumlException;
    public String getIface_package() throws XtumlException;
    public void setIface_package( String ref_iface_package ) throws XtumlException;
    public void setProvider_port_name( String ref_provider_port_name ) throws XtumlException;
    public String getProvider_port_name() throws XtumlException;
    public void setProvider_port_package( String ref_provider_port_package ) throws XtumlException;
    public String getProvider_port_package() throws XtumlException;
    public void setBase_class( String m_base_class ) throws XtumlException;
    public String getBase_class() throws XtumlException;
    public void setEndpoint( String m_endpoint ) throws XtumlException;
    public String getEndpoint() throws XtumlException;


    // operations
    public void render() throws XtumlException;
    public void render_acccessor() throws XtumlException;


    // selections
    default public void setR401_is_a_File( File inst ) {}
    public File R401_is_a_File() throws XtumlException;
    default public void setR4160_satisfies_provided_Port( Port inst ) {}
    public Port R4160_satisfies_provided_Port() throws XtumlException;
    default public void setR4160_satisfies_required_Port( Port inst ) {}
    public Port R4160_satisfies_required_Port() throws XtumlException;
    default public void setR417_passes_messages_for_ComponentDefinition( ComponentDefinition inst ) {}
    public ComponentDefinition R417_passes_messages_for_ComponentDefinition() throws XtumlException;
    default public void setR418_implements_Iface( Iface inst ) {}
    public Iface R418_implements_Iface() throws XtumlException;
    default public void addR420_provides_implementation_for_PortMessage( PortMessage inst ) {}
    default public void removeR420_provides_implementation_for_PortMessage( PortMessage inst ) {}
    public PortMessageSet R420_provides_implementation_for_PortMessage() throws XtumlException;
    default public void setR422_C_PO( C_PO inst ) {}
    public C_PO R422_C_PO() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/interfaces/Port.java <==
package io.ciera.tool.sql.architecture.interfaces;


import io.ciera.runtime.summit.classes.IModelInstance;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.architecture.component.ComponentDefinition;
import io.ciera.tool.sql.architecture.file.File;
import io.ciera.tool.sql.architecture.interfaces.Iface;
import io.ciera.tool.sql.architecture.interfaces.Port;
import io.ciera.tool.sql.architecture.interfaces.PortMessage;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.ooaofooa.component.C_PO;


public interface Port extends IModelInstance<Port,Sql> {

    // attributes
    public void setName( String ref_name ) throws XtumlException;
    public String getName() throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public String getPackage() throws XtumlException;
    public String getPort_name() throws XtumlException;
    public void setPort_name( String m_port_name ) throws XtumlException;
    public void setProvider( boolean m_provider ) throws XtumlException;
    public boolean getProvider() throws XtumlException;
    public void setComp_name( String ref_comp_name ) throws XtumlException;
    public String getComp_name() throws XtumlException;
    public String getComp_package() throws XtumlException;
    public void setComp_package( String ref_comp_package ) throws XtumlException;
    public String getIface_name() throws XtumlException;
    public void setIface_name( String ref_iface_name ) throws XtumlException;
    public String getIface_package() throws XtumlException;
    public void setIface_package( String ref_iface_package ) throws XtumlException;
    public String getProvider_port_name() throws XtumlException;
    public void setProvider_port_name( String ref_provider_port_name ) throws XtumlException;
    public String getProvider_port_package() throws XtumlException;
    public void setProvider_port_package( String ref_provider_port_package ) throws XtumlException;
    public void setBase_class( String m_base_class ) throws XtumlException;
    public String getBase_class() throws XtumlException;
    public String getImpl_class() throws XtumlException;
    public void setImpl_class( String m_impl_class ) throws XtumlException;
    public String getEndpoint() throws XtumlException;
    public void setEndpoint( String m_endpoint ) throws XtumlException;


    // operations
    public void render() throws XtumlException;
    public void render_acccessor() throws XtumlException;


    // selections
    default public void setR401_is_a_File( File inst ) {}
    public File R401_is_a_File() throws XtumlException;
    default public void setR4160_satisfies_provided_Port( Port inst ) {}
    public Port R4160_satisfies_provided_Port() throws XtumlException;
    default public void setR4160_satisfies_required_Port( Port inst ) {}
    public Port R4160_satisfies_required_Port() throws XtumlException;
    default public void setR417_passes_messages_for_ComponentDefinition( ComponentDefinition inst ) {}
    public ComponentDefinition R417_passes_messages_for_ComponentDefinition() throws XtumlException;
    default public void setR418_implements_Iface( Iface inst ) {}
    public Iface R418_implements_Iface() throws XtumlException;
    default public void addR420_provides_implementation_for_PortMessage( PortMessage inst ) {}
    default public void removeR420_provides_implementation_for_PortMessage( PortMessage inst ) {}
    public PortMessageSet R420_provides_implementation_for_PortMessage() throws XtumlException;
    default public void setR422_C_PO( C_PO inst ) {}
    public C_PO R422_C_PO() throws XtumlException;


}
